@@ -5,8 +5,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef INCIDENCEEDITOR_ALARMDIALOG_H
-#define INCIDENCEEDITOR_ALARMDIALOG_H
+#pragma once
 
 #include <KCalendarCore/Incidence>
 
@@ -52,5 +51,3 @@ private:
     bool mAllowEndReminders = true;
 };
 }
-
-#endif // INCIDENCEEDITOR_ALARMDIALOG_H
