@@ -8,8 +8,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef INCIDENCEEDITOR_ATTACHMENTEDITDIALOG_H
-#define INCIDENCEEDITOR_ATTACHMENTEDITDIALOG_H
+#pragma once
 
 #include <KCalendarCore/Attachment>
 #include <QDialog>
@@ -43,11 +42,9 @@ protected Q_SLOTS:
 
 private:
     KCalendarCore::Attachment mAttachment;
-    AttachmentIconItem *mItem = nullptr;
+    AttachmentIconItem *const mItem;
     QMimeType mMimeType;
     Ui::AttachmentEditDialog *const mUi;
     QPushButton *mOkButton = nullptr;
 };
 }
-
-#endif // INCIDENCEEDITOR_ATTACHMENTEDITDIALOG_H
